start_exit_incoming_ack_pipeline

Function start_exit_incoming_ack_pipeline 

async fn start_exit_incoming_ack_pipeline<AckIn>(ack_incoming: AckIn)
where AckIn: Stream<Item = (OffchainPublicKey, Vec<Acknowledgement>)> + Send + 'static,
Drains incoming acknowledgements without forwarding them to an [UnacknowledgedTicketProcessor].

Used by Exit nodes: they keep the incoming acknowledgement pipeline running (for future development), but since they never receive tickets, they have nothing to acknowledge.