async fn start_exit_incoming_ack_pipeline<AckIn>(ack_incoming: AckIn)Expand description
Drains incoming acknowledgements without forwarding them to an [UnacknowledgedTicketProcessor].
Used by Exit nodes: they keep the incoming acknowledgement pipeline running (for future development), but since they never receive tickets, they have nothing to acknowledge.